==> generator-jhipster-primeng-2.0.63.tgz: package/generators/app/templates/src/main/webapp/app/primeng/buttons/splitbutton/splitbuttondemo.component.ts <==
import { Component, OnInit } from '@angular/core';
import { JhiLanguageService } from 'ng-jhipster';
import {MenuItem, Message} from 'primeng/components/common/api';

@Component({
    selector: 'jhi-splitbutton',
    templateUrl: './splitbuttondemo.component.html',
    styles: []
})
export class SplitbuttonDemoComponent implements OnInit {
    msgs: Message[] = [];

    items: MenuItem[];
    itemsIcons: MenuItem[];

    activeIndex = 0;

    ngOnInit() {
        this.items = [
            {label: 'Update', command: () => {
                this.update();
            }},
            {label: 'Delete', command: () => {
                this.delete();
            }},
            {label: 'AngularConnect', url: 'https://www.angularconnect.com'}
        ];

        this.itemsIcons = [
            {label: 'Update', icon: 'fa-refresh', command: () => {
                this.update();
            }},
            {label: 'Delete', icon: 'fa-close', command: () => {
                this.delete();
            }},
            {label: 'AngularConnect', icon: 'fa-link', url: 'https://www.angularconnect.com'}
        ];
    }

    create() {
        this.msgs = [];
        this.msgs.push({severity: 'info', summary: 'Success', detail: 'AngularConnect user account is created'});
    }

    update() {
        this.msgs = [];
        this.msgs.push({severity: 'info', summary: 'Success', detail: 'AngularConnect user account is updated'});
    }

    delete() {
        this.msgs = [];
        this.msgs.push({severity: 'info', summary: 'Success', detail: 'AngularConnect user account is deleted'});
    }

    onChangeStep(label: string) {
        this.msgs.length = 0;
        this.msgs.push({severity: 'info', summary: label});
    }
}

==> generator-jhipster-primeng-2.3.0.tgz: package/generators/app/templates/src/main/webapp/app/primeng/buttons/splitbutton/splitbuttondemo.component.ts <==
import { Component, OnInit } from '@angular/core';
import { JhiLanguageService } from 'ng-jhipster';
import {MenuItem, Message} from 'primeng/components/common/api';

@Component({
    selector: 'jhi-splitbutton',
    templateUrl: './splitbuttondemo.component.html',
    styles: []
})
export class SplitbuttonDemoComponent implements OnInit {
    msgs: Message[] = [];

    items: MenuItem[];
    itemsIcons: MenuItem[];

    activeIndex = 0;

    ngOnInit() {
        this.items = [
            {label: 'Update', command: () => {
                this.update();
            }},
            {label: 'Delete', command: () => {
                this.delete();
            }},
            {label: 'AngularConnect', url: 'https://www.angularconnect.com'}
        ];

        this.itemsIcons = [
            {label: 'Update', icon: 'pi pi-refresh', command: () => {
                this.update();
            }},
            {label: 'Delete', icon: 'pi pi-times', command: () => {
                this.delete();
            }},
            {label: 'AngularConnect', icon: 'pi pi-info', url: 'https://www.angularconnect.com'}
        ];
    }

    create() {
        this.msgs = [];
        this.msgs.push({severity: 'info', summary: 'Success', detail: 'AngularConnect user account is created'});
    }

    update() {
        this.msgs = [];
        this.msgs.push({severity: 'info', summary: 'Success', detail: 'AngularConnect user account is updated'});
    }

    delete() {
        this.msgs = [];
        this.msgs.push({severity: 'info', summary: 'Success', detail: 'AngularConnect user account is deleted'});
    }

    onChangeStep(label: string) {
        this.msgs.length = 0;
        this.msgs.push({severity: 'info', summary: label});
    }
}
